@@ -2,6 +2,9 @@ use 5.010;
 use strict;
 use warnings;
 package Acme::Gtk2::Ex::Builder;
+BEGIN {
+  $Acme::Gtk2::Ex::Builder::VERSION = '0.003';
+}
 # ABSTRACT: Funny Gtk2 Interface Design Module
 
 use base qw( Exporter );
@@ -152,16 +155,17 @@ sub set  { goto &_set  }
 1;
 
 
-
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Acme::Gtk2::Ex::Builder - Funny Gtk2 Interface Design Module
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -221,10 +225,10 @@ It can contains several C<has> functions.
 =head2 has
 
 This function creates the Gtk2 widget.
-In fact when you use this, C<<Gtk2::XXX->new()>> will be called.
+In fact when you use this, C<< Gtk2::XXX->new >> will be called.
 See L<Gtk2> and Gtk2 API reference.
 
-Following code will call C<<Gtk2::Window->new()>>.
+Following code will call C<< Gtk2::Window->new >>.
 
     my $app = build {
         has Window;
@@ -291,7 +295,7 @@ C<packing> is used for L<Gtk2::VBox> and L<Gtk2::HBox>.
 =head2 on
 
 This function connects signals for specified widget.
-Actually it is same as C<<$widget->signal_connect>>.
+Actually it is same as C<< $widget->signal_connect >>.
 See L<Gtk2> and Gtk2 API reference.
 
     my $app = build {
@@ -313,7 +317,7 @@ See L<Gtk2> and Gtk2 API reference.
 =head2 set
 
 This function sets properties for specified widget.
-Actually it is same as C<<$widget->set_xxx>>.
+Actually it is same as C<< $widget->set_xxx >>.
 See L<Gtk2> and Gtk2 API reference.
 
     my $app = build {
@@ -341,10 +345,11 @@ contain children widgets.
 
 =head1 SEE ALSO
 
-The idea of this module is stealed from L<http://advent.perl.kr/2010-12-24.html>.
-I hope L<Gtk2::Ex::Builder> will be released by the article's author someday.
-And before release this module colud be helpful for you
-who likes Gtk2 but too lazy to type all code by his/her own hand.
+The idea of this module is stealed from
+L<Seoul.pm Perl Advent Calendar, 2010-12-24|http://advent.perl.kr/2010-12-24.html>.
+I think L<Gtk2::Ex::Builder> will be released someday by the article's author.
+But before the release, this module colud be helpful for you
+who likes L<Gtk2> but too lazy to type all code by his/her own hands.
 
 =head1 AUTHOR
 
